@@ -6,14 +6,6 @@ library(pedbp)
 x <- tryCatch(q_bp(p_sbp = 1, p_dbp = 1, male = 1, age = numeric(1), source = "Not a real source"), error = function(e) e)
 stopifnot(inherits(x, "error"))
 
-# the message appears to print in one of two ways, using the unicode \u8220 and
-# \u8221 for the double quotes when in an interactive session, and \u22 when not
-# interactive
-stopifnot(
-          identical(x$message, "'arg' should be one of “martin2022”, “gemelli1990”, “nhlbi”, “lo2013”, “flynn2017”") |
-          identical(x$message, "'arg' should be one of \"martin2022\", \"gemelli1990\", \"nhlbi\", \"lo2013\", \"flynn2017\"")
-)
-
 ################################################################################
 qbp_expected <- list(sbp = rep(NA_real_, 9), dbp = rep(NA_real_, 9))
 
